<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_956cd32298a229f" . "9768f1096f077ace" . "3" => base64_decode("Ym9keS1wbGF" . "pbg=="), "_9c050c78" . "6fc87170c" . "bb84fc6a8" . "b13cb6" => base64_decode("YXR0YWNo" . "bWVudC0="), "_f39f5346e313e4dd1ac3a7bd" . "8032beda" => base64_decode("c3Vic3RyX2NvbX" . "BhcmU="), "_8c575917cbaedf1e7efae849394" . "02bff" => base64_decode("U3V" . "iam" . "Vjd" . "A=="), "_618a4aeb9fecc4592a4521f34876fa2" . "9" => base64_decode("ZnJ" . "vbQ" . "=="), "_44e986c0" . "4f41a08b5" . "6a383c7b3" . "a88ee2" => base64_decode("c2Vu" . "ZGVy"), "_97ea09a7faf27c52c6eff697" . "73df1d8a" => base64_decode("dGlt" . "ZXN0" . "YW1w"), "_a1e707d02a236dadebd15a45e65e" . "bdb6" => base64_decode("YXR0YWNob" . "WVudC1jb3" . "VudA=="), "_f589476007fa133f457c3ef29dd" . "fa566" => base64_decode("VG8" . "="), "_d706c160e45bf7434fff82a5976f0e1" . "9" => base64_decode("YXJy" . "YXlf" . "a2V5" . "cw=="), "_6e1c717cf3cbf1af982ed74d4336" . "b7f1" => base64_decode("Ym9keS" . "1odG1s"), "_1d6c68a0262e8fa0bed" . "1215b7224a98e" => base64_decode("cmV" . "jaX" . "BpZ" . "W50"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_d706c160e45bf7434ff" . "f82a5976f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_a1e707d02a236" . "dadebd15a45e65" . "ebdb6"] && $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_f39f5346e313e4d" . "d1ac3a7bd8032bed" . "a"]($key, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_9c050c786fc87170cbb84fc6a8b13cb" . "6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_1d6c68a0262e" . "8fa0bed1215b7" . "224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_618a4aeb9fecc4592a4521f34876fa2" . "9"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_f589476007fa133f457c3ef29ddf" . "a566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_8c575917cbaedf1e7efae849394" . "02bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_6e1c717cf3cbf1af982ed74d4336" . "b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_956cd32298a229" . "f9768f1096f077a" . "ce3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_97ea09a7faf27c5" . "2c6eff69773df1d8" . "a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_44e986c04f41a08b56" . "a383c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}