<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array("_67a0d624aebc" . "ceb0abd5ce56a" . "53ff06f" => base64_decode("ZG" . "F0" . "ZQ" . "=="), "_460e1aeb3113a1676ce59a8f40431" . "d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0dXJlIHByb2pl" . "Y3Q="), "_5d40a2cf1c525fb25" . "2bf5599e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdC" . "B3YXMgaWRlbnRpZmllZCBmb3IgbWFp" . "bDsgc3ViamVjdCAn"), "_e608e5b5c4c34a67ba97ef84c1e1619" . "9" => base64_decode("Jw" . "=="), "project_i" . "d" => base64_decode("cHJvamVjdF9" . "pZA=="), "_f656816961e8573806141" . "c558b184fe2" => base64_decode("c3V" . "iam" . "Vjd" . "A=="), "_bfda889b74ea561b14325" . "e30e7d75426" => base64_decode("Ym9keV9od" . "G1s"), "_c35473364" . "fa7a050299" . "058f332ec2" . "9c1" => base64_decode("ZXhjZXB0aW" . "9u"), "_03b1f0cee" . "835582d115" . "8dce2678b5" . "05c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCByZWNlaXZlZCBzdWJzY3JpYmV" . "y"), "_9b16fa2683095" . "e67d7c8b265a80" . "81d0b" => base64_decode("TWFpbFJlY2" . "VpdmVkRXZl" . "bnRSZWNlaX" . "Zlcg=="), "_376d30c40857357a4d4cbb1ffaa2" . "5817" => base64_decode("dG8" . "="), "_ced92d7b391285c8a26" . "846f1f4bd3128" => base64_decode("Ym9keV90ZX" . "h0"), "_618a4aeb9fecc4592a4521f3" . "4876fa29" => base64_decode("ZnJvb" . "Q=="), "_a3d82c5df3" . "8e194c9c73e" . "3ccb4223bbc" => base64_decode("ZW1haWx" . "fZGF0YQ" . "=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_9b16fa2683095e67d7c8b26" . "5a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_03b1f0cee835582d1" . "158dce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_5d40a2cf1c525fb252bf5" . "599e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_e608e5b5c4c34a67ba97ef84c" . "1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_618a4aeb9fecc4592a4521f3" . "4876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_376d30c40857357a4" . "d4cbb1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_f656816961e8573806141c558b1" . "84fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_ced92d7b391285c8a26846f1f4bd" . "3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_bfda889b74ea561b14325e30e7d7" . "5426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_67a0d624aebcceb0abd" . "5ce56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_460e1aeb3113a1" . "676ce59a8f40431" . "d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["proj" . "ect_" . "id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_a3d82c5df38e194c9c73e3ccb4223bb" . "c"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_c35473364fa7a05" . "0299058f332ec29c" . "1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}